// src/matchers/toPassAxe/index.ts
import { test as test4 } from "@playwright/test";

// src/utils/options.ts
import { test } from "@playwright/test";
import merge from "merge-deep";
function getOptions(options = {}) {
  const info = test.info();
  return merge(info.project.use.axeOptions, options);
}

// src/matchers/toPassAxe/index.ts
import createHTMLReport from "axe-reporter-html";

// src/utils/attachments.ts
import path from "node:path";
import fs from "node:fs/promises";
import { test as test2 } from "@playwright/test";
async function attach(info, name, data) {
  const outPath = path.join(info.outputPath(), name);
  await fs.writeFile(outPath, data, "utf8");
  info.attachments.push({
    name,
    path: outPath,
    contentType: `application/${path.extname(name)}`
  });
}

// src/utils/locator.ts
function isLocator(value) {
  return value.constructor.name === "Locator";
}
function resolveLocator(handle) {
  return isLocator(handle) ? handle : handle.locator("body");
}

// src/utils/poll.ts
import { test as test3 } from "@playwright/test";
function getTimeout(timeout) {
  return timeout ?? test3.info()?._expect?.timeout ?? 5e3;
}
async function poll(locator, timeout, predicate) {
  let result = null;
  let expired = false;
  const timer = setTimeout(() => {
    expired = true;
  }, getTimeout(timeout));
  try {
    while (true) {
      if (expired)
        return result;
      result = await predicate();
      if (expired || result.ok)
        return result;
      await locator.evaluate(
        () => new Promise((resolve2) => setTimeout(resolve2, 250))
      );
    }
  } catch (e) {
  } finally {
    clearTimeout(timer);
  }
  return result;
}

// src/utils/axe.ts
import fs2 from "node:fs";
import resolve from "isomorphic-resolve";
async function injectAxe(locator) {
  if (await locator.evaluate(() => !!window.axe?.run)) {
    return;
  }
  const filePath = resolve("axe-core/axe.min.js");
  const axe = await fs2.promises.readFile(filePath, "utf-8");
  await locator.evaluate((_, axe2) => window.eval(axe2), axe);
}
function runAxe(locator, options = {}) {
  return locator.evaluate(
    (el, options2) => window.axe.run(el, options2),
    options
  );
}

// src/waitForAxeResults.ts
async function waitForAxeResults(handle, { timeout, ...options } = {}) {
  const opts = getOptions(options);
  const locator = resolveLocator(handle);
  await injectAxe(locator);
  return poll(locator, timeout, async () => {
    const results = await runAxe(locator, opts);
    return {
      ok: !results.violations.length,
      results
    };
  });
}

// src/matchers/toPassAxe/index.ts
var summarize = (violations) => violations.map((violation) => `${violation.id}(${violation.nodes.length})`).join(", ");
async function getResults(obj, options) {
  if (obj.violations) {
    const results = obj;
    return {
      results,
      ok: !results.violations.length
    };
  } else {
    return waitForAxeResults(obj, options);
  }
}
async function toPassAxe(obj, options = {}) {
  try {
    const { results, ok } = await getResults(obj, options);
    if (!ok) {
      const info = test4.info();
      const opts = getOptions(options);
      const html = await createHTMLReport(results);
      const filename = opts.filename || "axe-report.html";
      await attach(info, filename, html);
    }
    return {
      pass: ok,
      message: () => {
        return this.utils.matcherHint("toPassAxe", void 0, void 0, this) + `

Expected: No violations
Received: ${results.violations.length} violations

Violations: ${summarize(results.violations)}`;
      }
    };
  } catch (err) {
    return {
      pass: false,
      message: () => err.message
    };
  }
}

// src/matchers/index.ts
var matchers_default = {
  toPassAxe
};

// src/index.ts
var src_default = matchers_default;
export {
  src_default as default,
  waitForAxeResults
};
